# unfolded.map_sdk

Unfolded Map SDK for Jupyter (Python).

Refer to the documentation website for [how to install](https://location.foursquare.com/studio/docs/cloud-notebooks), [API documentation](https://location.foursquare.com/developer/docs/studio-map-sdk-api-reference), and [examples](https://github.com/foursquare/unfolded-sdk-examples/tree/master/notebooks).
